@@ -41,8 +41,6 @@ avatar_chooser (void)
     g_assert (chooser != NULL);
 
     /* Check that all the child widgets were successfully instantiated. */
-    g_assert (gtk_test_find_widget (chooser, "Take a Photo", GTK_TYPE_BUTTON)
-        != NULL);
     select_button = gtk_test_find_widget (chooser, "Select", GTK_TYPE_BUTTON);
     g_assert (select_button != NULL);
     g_assert (GTK_IS_BUTTON (select_button));
@@ -98,7 +96,6 @@ static void widget (void)
 
 int main (int argc, gchar *argv[])
 {
-    gdk_threads_init ();
     gtk_test_init (&argc, &argv, NULL);
     if (!cheese_gtk_init (&argc, &argv))
         return EXIT_FAILURE;
